==> jquery-stockcharts-1.0.1.tgz: package/README.md <==
﻿﻿<div align="center">
	<a href="https://www.npmjs.com/~canvasjs" target="_blank">
		<img src="https://canvasjs.com/wp-content/uploads/images/logo/canvasjs-logo-240x100.png" alt="CanvasJS"/>
	</a>
</div>

# CanvasJS jQuery StockCharts - Official

CanvasJS <a>[jQuery StockChart](https://canvasjs.com/jquery-charts/#stockcharts) for creating interactive charts & graphs for your web pages. Library supports a wide range of chart types including line, area, column, candlestick, etc.
<br/><br/>

<a href="https://canvasjs.com/javascript-stockcharts/"><img src="https://canvasjs.com/wp-content/uploads/images/npm/jquery/jquery-stockcharts.jpg" alt="jQuery Charts"></a>
<br/><br/>

## Links

-   [Official Website](https://canvasjs.com/)
-   [jQuery StockCharts Demo](https://canvasjs.com/jquery-charts/#stockcharts)
-   [Download CanvasJS](https://canvasjs.com/download-html5-charting-graphing-library/)
-   [jQuery StockChart Integration](https://canvasjs.com/docs/stockcharts/integration/jquery/)
-   [StockChart Documentation](https://canvasjs.com/docs/stockcharts/basics-of-creating-html5-stockchart/)
-   [StockChart Support Forum](https://canvasjs.com/forums/forum/stockchart-support/)
    <br/><br/>

## Installing CanvasJS jQuery StockCharts

Install CanvasJS StockCharts package to your project.

#### Install jQuery StockChart via NPM

```
npm install --save @canvasjs/jquery-stockcharts
```

See [npm documentation](https://docs.npmjs.com/) to know more about npm usage.

#### Using CanvasJS jQuery StockCharts via CDN
You can access CanvasJS jQuery StockCharts from our CDN  directly. The plugin has a dependency on jQuery, and hence that has to be imported as well.
```
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js"></script>
<script src="https://cdn.canvasjs.com/ga/jquery.canvasjs.stock.min.js"></script>
```


#### Download from Official Site
You can download the jQuery plugin along with examples from our official [download page](https://canvasjs.com/download-html5-charting-graphing-library/). Save it in your project directory & add it in your application.
```
<script src="jquery.canvasjs.stock.min.js"></script>
```

<br/>

## Usage

As CanvasJS jQuery StockCharts package is installed, it can be imported into your project. As the plugin has a dependency on jQuery, you have to import that as well.

```
//Load jQuery and CanvasJS jQuery StockCharts
import $ from "jquery";
import "@canvasjs/jquery-charts";
```

#### Define container for the stockchart.

```
<div id="stockChartContainer"></div>
```

#### Create stockChart

```
    var stockChartOptions = {
        title: {
            text: "CanvasJS StockChart"
        },
        charts: [{
            data: [{
                type: "line",
                dataPoints: [
                    { x: new Date("2018-01-01"), y: 71 },
                    { x: new Date("2018-02-01"), y: 55 },
                    { x: new Date("2018-03-01"), y: 50 },
                    { x: new Date("2018-04-01"), y: 65 },
                    { x: new Date("2018-05-01"), y: 95 },
                    { x: new Date("2018-06-01"), y: 68 },
                    { x: new Date("2018-07-01"), y: 28 },
                    { x: new Date("2018-08-01"), y: 34 },
                    { x: new Date("2018-09-01"), y: 14 },
                    { x: new Date("2018-10-01"), y: 71 },
                    { x: new Date("2018-11-01"), y: 55 },
                    { x: new Date("2018-12-01"), y: 50 },
                    { x: new Date("2019-01-01"), y: 34 },
                    { x: new Date("2019-02-01"), y: 50 },
                    { x: new Date("2019-03-01"), y: 50 },
                    { x: new Date("2019-04-01"), y: 95 },
                    { x: new Date("2019-05-01"), y: 68 },
                    { x: new Date("2019-06-01"), y: 28 },
                    { x: new Date("2019-07-01"), y: 34 },
                    { x: new Date("2019-08-01"), y: 65 },
                    { x: new Date("2019-09-01"), y: 55 },
                    { x: new Date("2019-10-01"), y: 71 },
                    { x: new Date("2019-11-01"), y: 55 },
                    { x: new Date("2019-12-01"), y: 50 }
                ]
            }]
        }],
        navigator: {
            slider: {
                minimum: new Date("2018-07-01"),
                maximum: new Date("2019-06-30")
            }
        }
    };

    $("#stockChartContainer").CanvasJSStockChart(stockChartOptions);
```

<br/>

<img src="https://canvasjs.com/wp-content/uploads/images/npm/jquery/jquery-stockchart.png" alt="jQuery StockChart">

<br/>

#### Interactive jQuery StockCharts

![jQuery Interactive StockCharts](https://canvasjs.com/wp-content/uploads/images/npm/stockchart-interactivity.gif)

==> jquery-stockcharts-1.0.2.tgz: package/README.md <==
﻿﻿<div align="center">
	<a href="https://www.npmjs.com/~canvasjs" target="_blank">
		<img src="https://canvasjs.com/wp-content/uploads/images/logo/canvasjs-logo-240x100.png" alt="CanvasJS"/>
	</a>
</div>

# CanvasJS jQuery StockCharts - Official

CanvasJS <a>[jQuery StockChart](https://canvasjs.com/jquery-charts/#stockcharts) for creating interactive charts & graphs for your web pages. Library supports a wide range of chart types including line, area, column, candlestick, etc.
<br/><br/>

<a href="https://canvasjs.com/jquery-charts/#stockcharts"><img src="https://canvasjs.com/wp-content/uploads/images/npm/jquery/jquery-stockcharts.jpg" alt="jQuery Charts"></a>
<br/><br/>

## Important Links

- [Official Website](https://canvasjs.com/)
- [jQuery StockCharts Demo](https://canvasjs.com/jquery-charts/#stockcharts)
- [Download CanvasJS](https://canvasjs.com/download-html5-charting-graphing-library/)
- [jQuery StockChart Integration](https://canvasjs.com/docs/stockcharts/integration/jquery/)
- [StockChart Documentation](https://canvasjs.com/docs/stockcharts/basics-of-creating-html5-stockchart/)
- [StockChart Support Forum](https://canvasjs.com/forums/forum/stockchart-support/)
<br/><br/>

## Installing CanvasJS jQuery StockCharts
There are multiple ways to install CanvasJS jQuery StockCharts. You can directly add script-tag to include it from [CDN or download it from official site](https://canvasjs.com/download-html5-charting-graphing-library/) or install it from [NPM registry](https://npmjs.org/package/@canvasjs/jquery-stockcharts).

#### Install jQuery StockChart via NPM

```
npm install --save @canvasjs/jquery-stockcharts
```

See [npm documentation](https://docs.npmjs.com/) to know more about npm usage.

#### Using CanvasJS jQuery StockCharts via CDN
You can access CanvasJS jQuery StockCharts from our CDN directly. The plugin has a dependency on jQuery, and hence that has to be imported as well.
```
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js"></script>
<script src="https://cdn.canvasjs.com/ga/jquery.canvasjs.stock.min.js"></script>
```

#### Download from Official Site
You can download the jQuery plugin along with examples from our official [download page](https://canvasjs.com/download-html5-charting-graphing-library/). Save it in your project directory & add it in your application.
```
<script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js"></script>
<script src="jquery.canvasjs.stock.min.js"></script>
```

<br/>

## Usage

After CanvasJS jQuery StockCharts is installed, it can be imported into your project.

```
//Load jQuery and CanvasJS jQuery StockCharts
import $ from "jquery";
import "@canvasjs/jquery-charts";
```

#### Define container for the StockChart.

```
<div id="stockChartContainer"></div>
```

#### Create StockChart

```
    var stockChartOptions = {
        title: {
            text: "CanvasJS StockChart"
        },
        charts: [{
            data: [{
                type: "line",
                dataPoints: [
                    { x: new Date("2018-01-01"), y: 71 },
                    { x: new Date("2018-02-01"), y: 55 },
                    { x: new Date("2018-03-01"), y: 50 },
                    { x: new Date("2018-04-01"), y: 65 },
                    { x: new Date("2018-05-01"), y: 95 },
                    { x: new Date("2018-06-01"), y: 68 },
                    { x: new Date("2018-07-01"), y: 28 },
                    { x: new Date("2018-08-01"), y: 34 },
                    { x: new Date("2018-09-01"), y: 14 },
                    { x: new Date("2018-10-01"), y: 71 },
                    { x: new Date("2018-11-01"), y: 55 },
                    { x: new Date("2018-12-01"), y: 50 },
                    { x: new Date("2019-01-01"), y: 34 },
                    { x: new Date("2019-02-01"), y: 50 },
                    { x: new Date("2019-03-01"), y: 50 },
                    { x: new Date("2019-04-01"), y: 95 },
                    { x: new Date("2019-05-01"), y: 68 },
                    { x: new Date("2019-06-01"), y: 28 },
                    { x: new Date("2019-07-01"), y: 34 },
                    { x: new Date("2019-08-01"), y: 65 },
                    { x: new Date("2019-09-01"), y: 55 },
                    { x: new Date("2019-10-01"), y: 71 },
                    { x: new Date("2019-11-01"), y: 55 },
                    { x: new Date("2019-12-01"), y: 50 }
                ]
            }]
        }],
        navigator: {
            slider: {
                minimum: new Date("2018-07-01"),
                maximum: new Date("2019-06-30")
            }
        }
    };

    $("#stockChartContainer").CanvasJSStockChart(stockChartOptions);
```

<br/>

<img src="https://canvasjs.com/wp-content/uploads/images/npm/jquery/jquery-stockchart.png" alt="jQuery StockChart">

<br/>

#### Interactive jQuery StockCharts

![jQuery Interactive StockCharts](https://canvasjs.com/wp-content/uploads/images/npm/stockchart-interactivity.gif)

<br/>

### Related StockChart Packages
- [JavaScript StockCharts](https://www.npmjs.com/package/@canvasjs/stockcharts)
- [React StockCharts](https://www.npmjs.com/package/@canvasjs/react-stockcharts)
- [Angular StockCharts](https://www.npmjs.com/package/@canvasjs/angular-stockcharts)
- [Vue StockCharts](https://www.npmjs.com/package/@canvasjs/vue-stockcharts)
